@@ -26,7 +26,7 @@ PRIV=$LIMAN_ROOT/lib/${PLATFORM}/${PRODUCT}/${PRODUCT}_private.key
 echo Product: $PRODUCT
 echo Private key file: $PRIV
 echo Public key file: $PUB
-#$LIMGEN --product=$PRODUCT --major=1 --minor=0 -T --privkeyfile=$PRIV  --pubkeyfile=$PUB $1 $2 $3 $4 $5
+$LIMGEN --product=$PRODUCT --major=1 --minor=0 -T --privkeyfile=$PRIV  --pubkeyfile=$PUB $1 $2 $3 $4 $5
 echo
 echo Check command used to generate the license:
 echo $LIMGEN --product=$PRODUCT --major=1 --minor=0 -T --privkeyfile=$PRIV  --pubkeyfile=$PUB $1 $2 $3 $4 $5
